#!/usr/bin/env python
from setuptools import setup
setup(
    name="segfault",
    version="0.0.1",
    author="Sean Kelly",
    author_email="sean.kelly.2992@gmail.com",
    description="A library that makes the Python interpreter segfault.",
    license="MIT",
    url='https://github.com/cbgbt/segfault',
    download_url='https://github.com/cbgbt/segfault/archive/v0.0.1.tar.gz',
    keywords="segfault",
    py_modules=['segfault', 'satire'],
)
